@@ -16,10 +16,10 @@
 #include <sys/param.h>
 #if 0
 #include <linux/quota.h>
-#define CONFFILE "/etc/telequotad.conf"
+#define CONFFILE "/etc/hubzero/telequotad.conf"
 #else
 #include <sys/quota.h>
-#define CONFFILE "/etc/telequotad.conf"
+#define CONFFILE "/etc/hubzero/telequotad.conf"
 #endif
 
 #include <sys/socket.h>
